@@ -249,22 +249,22 @@ def create_key_vault_reference_connection_if_not_exist(cmd, client, source_id, k
 
 
 def get_auth_if_no_valid_key_vault_connection(source_name, source_id, key_vault_connections):
+    if source_name == RESOURCE.WebApp:
+        return get_auth_if_no_valid_key_vault_connection_for_webapp(source_id, key_vault_connections)
+
+    if source_name == RESOURCE.ContainerApp:
+        return get_auth_if_no_valid_key_vault_connection_for_containerapp(key_vault_connections)
+
+    # any connection with csi enabled is a valid connection
+    if source_name == RESOURCE.KubernetesCluster:
+        for connection in key_vault_connections:
+            if connection.get('targetService', dict()).get(
+                    'resourceProperties', dict()).get('connectAsKubernetesCsiDriver'):
+                return
+        return {'authType': 'userAssignedIdentity'}
+
+    # other source types
     if key_vault_connections:
-        if source_name == RESOURCE.WebApp:
-            return get_auth_if_no_valid_key_vault_connection_for_webapp(source_id, key_vault_connections)
-
-        if source_name == RESOURCE.ContainerApp:
-            return get_auth_if_no_valid_key_vault_connection_for_containerapp(key_vault_connections)
-
-        # any connection with csi enabled is a valid connection
-        if source_name == RESOURCE.KubernetesCluster:
-            for connection in key_vault_connections:
-                if connection.get('target_service', dict()).get(
-                        'resource_properties', dict()).get('connect_as_kubernetes_csi_driver'):
-                    return
-            return {'authType': 'userAssignedIdentity'}
-
-        # other source types
         logger.warning('key vault reference connection: %s',
                        key_vault_connections[0].get('id'))
         return
@@ -333,6 +333,50 @@ def get_auth_if_no_valid_key_vault_connection_for_containerapp(key_vault_connect
     return {'authType': auth_type}
 
 
+def create_app_config_connection_if_not_exist(cmd, client, source_id, app_config_id,
+                                              scope=None):  # Resource.ContainerApp
+    from ._validators import get_source_resource_name
+
+    logger.warning('looking for valid app configuration connections')
+    for connection in client.list(resource_uri=source_id):
+        connection = todict(connection)
+        if connection.get('targetService', dict()).get('id') == app_config_id:
+            logger.warning('Valid app configuration connection found.')
+            return
+
+    logger.warning('no valid app configuration connection found. Creating with system identity...')
+
+    from ._resource_config import (
+        CLIENT_TYPE
+    )
+
+    connection_name = generate_random_string(prefix='appconfig_')
+    parameters = {
+        'target_service': {
+            "type": "AzureResource",
+            "id": app_config_id
+        },
+        'auth_info': {
+            'authType': 'systemAssignedIdentity'
+        },
+        # Container App container name
+        'scope': scope,
+        'client_type': CLIENT_TYPE.Blank,
+    }
+
+    source_name = get_source_resource_name(cmd)
+    if source_name == RESOURCE.KubernetesCluster:
+        parameters['target_service']['resource_properties'] = {
+            'type': 'KeyVault',
+            'connect_as_kubernetes_csi_driver': True,
+        }
+
+    return auto_register(client.begin_create_or_update,
+                         resource_uri=source_id,
+                         linker_name=connection_name,
+                         parameters=parameters)
+
+
 def is_packaged_installed(package_name):
     import pkg_resources
     installed_packages = pkg_resources.working_set
@@ -343,17 +387,24 @@ def is_packaged_installed(package_name):
 
 
 def get_object_id_of_current_user():
-    signed_in_user = run_cli_cmd('az account show').get('user')
+    signed_in_user_info = run_cli_cmd('az account show -o json')
+    if not isinstance(signed_in_user_info, dict):
+        raise CLIInternalError(
+            f"Can't parse login user information {signed_in_user_info}")
+    signed_in_user = signed_in_user_info.get('user')
     user_type = signed_in_user.get('type')
+    if not user_type or not signed_in_user.get('name'):
+        raise CLIInternalError(
+            f"Can't get user type or name from signed-in user {signed_in_user}")
     try:
         if user_type == 'user':
-            user_info = run_cli_cmd('az ad signed-in-user show')
+            user_info = run_cli_cmd('az ad signed-in-user show -o json')
             user_object_id = user_info.get('objectId') if user_info.get(
                 'objectId') else user_info.get('id')
             return user_object_id
         if user_type == 'servicePrincipal':
             user_info = run_cli_cmd(
-                f'az ad sp show --id {signed_in_user.get("name")}')
+                f'az ad sp show --id {signed_in_user.get("name")} -o json')
             user_object_id = user_info.get('id')
             return user_object_id
     except CLIInternalError as e:
@@ -365,7 +416,7 @@ def get_object_id_of_current_user():
 
 def get_cloud_conn_auth_info(secret_auth_info, secret_auth_info_auto,
                              user_identity_auth_info, system_identity_auth_info,
-                             service_principal_auth_info_secret, new_addon):
+                             service_principal_auth_info_secret, new_addon, auth_action=None, config_action=None):
     all_auth_info = []
     if secret_auth_info is not None:
         all_auth_info.append(secret_auth_info)
@@ -377,9 +428,15 @@ def get_cloud_conn_auth_info(secret_auth_info, secret_auth_info_auto,
         all_auth_info.append(system_identity_auth_info)
     if service_principal_auth_info_secret is not None:
         all_auth_info.append(service_principal_auth_info_secret)
+    if len(all_auth_info) == 0:
+        if auth_action == 'optOutAllAuth' and config_action == 'optOut':
+            return None
+        raise ValidationError('At least one auth info is needed')
     if not new_addon and len(all_auth_info) != 1:
         raise ValidationError('Only one auth info is needed')
     auth_info = all_auth_info[0] if len(all_auth_info) == 1 else None
+    if auth_info is not None and auth_action is not None:
+        auth_info.update({'auth_mode': auth_action})
     return auth_info
 
 
@@ -474,3 +531,19 @@ Learn more at https://spring.io/projects/spring-cloud-azure#overview"
         warning_message += both_version_message
 
     return warning_message
+
+
+# LinkerResource Model is converted into dict in update flow,
+# which conflicts with the default behavior of creation wrt the key name format.
+def get_auth_type_for_update(authInfo):
+    if 'auth_type' in authInfo:
+        return authInfo['auth_type']
+    return authInfo['authType']
+
+
+def get_secret_type_for_update(authInfo):
+    if 'secret_info' in authInfo:
+        return authInfo['secret_info']['secret_type']
+    if 'secretInfo' in authInfo:
+        return authInfo['secretInfo']['secretType']
+    return ''
