@@ -42,7 +42,8 @@ from ._resource_config import (
     LOCAL_CONNECTION_RESOURCE,
     LOCAL_CONNECTION_PARAMS,
     SPRING_APP_DEPLOYMENT_RESOURCE,
-    WEB_APP_SLOT_RESOURCE
+    WEB_APP_SLOT_RESOURCE,
+    OPT_OUT_OPTION,
 )
 
 
@@ -282,6 +283,16 @@ def get_local_context_value(cmd, arg):
     return None
 
 
+def opt_out_auth(namespace):
+    '''Validate if config and auth are both opted out
+    '''
+    opt_out_list = namespace.opt_out_list
+    if opt_out_list is not None and \
+            OPT_OUT_OPTION.AUTHENTICATION.value in opt_out_list:
+        return True
+    return False
+
+
 def intelligent_experience(cmd, namespace, missing_args):
     '''Use local context and interactive inputs to get arg values
     '''
@@ -292,6 +303,11 @@ def intelligent_experience(cmd, namespace, missing_args):
         if getattr(namespace, arg, None) is not None:
             cmd_arg_values[arg] = getattr(namespace, arg)
 
+    opt_out_auth_message = ''
+    if opt_out_auth(namespace):
+        opt_out_auth_message += '. Auth info is only used to generate configurations. ' + \
+            'Skip enabling identity and role assignments.'
+
     # for auth info without additional parameters
     if 'secret_auth_info_auto' in missing_args:
         cmd_arg_values['secret_auth_info_auto'] = {
@@ -302,7 +318,7 @@ def intelligent_experience(cmd, namespace, missing_args):
         cmd_arg_values['system_identity_auth_info'] = {
             'auth_type': 'systemAssignedIdentity'
         }
-        logger.warning('Auth info is not specified, use default one: --system-identity')
+        logger.warning('Auth info is not specified, use default one: --system-identity%s', opt_out_auth_message)
     elif 'user_account_auth_info' in missing_args:
         cmd_arg_values['user_account_auth_info'] = {
             'auth_type': 'userAccount'
@@ -427,6 +443,17 @@ def validate_target_resource_id(cmd, namespace):
     return False
 
 
+def validate_opt_out_auth_and_config(namespace):
+    '''Validate if config and auth are both opted out
+    '''
+    opt_out_list = namespace.opt_out_list
+    if opt_out_list is not None and \
+            OPT_OUT_OPTION.AUTHENTICATION.value in opt_out_list and \
+            OPT_OUT_OPTION.CONFIGURATION_INFO.value in opt_out_list:
+        return True
+    return False
+
+
 def get_missing_source_args(cmd, namespace):
     '''Get source resource related args
     '''
@@ -479,14 +506,6 @@ def get_missing_auth_args(cmd, namespace):
     target = get_target_resource_name(cmd)
     missing_args = dict()
 
-    # when keyvault csi is enabled, auth_type is userIdentity without subs_id and client_id
-    if source == RESOURCE.KubernetesCluster and target == RESOURCE.KeyVault\
-            and getattr(namespace, 'enable_csi', None):
-        setattr(namespace, 'user_identity_auth_info', {
-            'auth_type': 'userAssignedIdentity'
-        })
-        return missing_args
-
     # check if there are auth_info related params
     auth_param_exist = False
     for _, params in AUTH_TYPE_PARAMS.items():
@@ -495,6 +514,26 @@ def get_missing_auth_args(cmd, namespace):
                 auth_param_exist = True
                 break
 
+    # when keyvault csi is enabled, auth_type is userIdentity without subs_id and client_id
+    if source == RESOURCE.KubernetesCluster and target == RESOURCE.KeyVault:
+        if getattr(namespace, 'enable_csi', None):
+            if auth_param_exist:
+                logger.warning('When CSI driver is enabled (--enable-csi), \
+                               Service Connector uses the user assigned managed identity generated by AKS \
+                               azure-keyvault-secrets-provider add-on to authenticate. \
+                               Additional auth info is ignored.')
+            setattr(namespace, 'user_identity_auth_info', {
+                'auth_type': 'userAssignedIdentity'
+            })
+            return missing_args
+        if not auth_param_exist:
+            setattr(namespace, 'enable_csi', True)
+            setattr(namespace, 'user_identity_auth_info', {
+                'auth_type': 'userAssignedIdentity'
+            })
+            logger.warning('Auth info is not specified, use secrets store csi driver as default: --enable-csi')
+            return missing_args
+
     if source and target and not auth_param_exist:
         default_auth_type = SUPPORTED_AUTH_TYPE.get(source, {}).get(target, {})[0]
 
@@ -591,7 +630,8 @@ def validate_create_params(cmd, namespace):
     missing_args.update(get_missing_source_create_args(cmd, namespace))
     if not validate_target_resource_id(cmd, namespace):
         missing_args.update(get_missing_target_args(cmd))
-    missing_args.update(get_missing_auth_args(cmd, namespace))
+    if not validate_opt_out_auth_and_config(namespace):
+        missing_args.update(get_missing_auth_args(cmd, namespace))
     return missing_args
 
 
@@ -621,7 +661,7 @@ def validate_update_params(cmd, namespace):
     missing_args = dict()
     if not validate_connection_id(namespace):
         missing_args.update(get_missing_source_args(cmd, namespace))
-    missing_args.update(get_missing_auth_args(cmd, namespace))
+    # missing_args.update(get_missing_auth_args(cmd, namespace))
     missing_args.update(get_missing_connection_name(namespace))
     return missing_args
 
